@@ -126,7 +126,7 @@ setTimeout( 'ShowTimeoutWarning();', session_maxlifetime_ms );
 					<td class="main_menu_td_content">
 						<?php
 						if (isset($section) && $section == "magazine") {
-						    echo "<span class='txt_highlight2'>" . $lang['href_selection'] . "</span";
+						    echo "<span class='txt_highlight2'>" . $lang['href_selection'] . "</span>";
 						}
 						else {
 						    echo "<a href='mag_overview.php'>" . $lang['href_selection'] . "</a>";
@@ -139,7 +139,7 @@ setTimeout( 'ShowTimeoutWarning();', session_maxlifetime_ms );
 					<td class="main_menu_td_content">
 						<?php
 						if (isset($section) && $section == "message") {
-						    echo "<span class='txt_highlight2'>" . $lang['href_messages'] . "</span";
+						    echo "<span class='txt_highlight2'>" . $lang['href_messages'] . "</span>";
 						}
 						else {
 						    echo "<a href='msg_list.php'>" . $lang['href_messages'] . "&nbsp;(" . $me['mail'] . ")</a>";
@@ -152,7 +152,7 @@ setTimeout( 'ShowTimeoutWarning();', session_maxlifetime_ms );
 					<td class="main_menu_td_content">
 						<?php
 						if (isset($section) && $section == "my") {
-							echo "<span class='txt_highlight2'>" . $lang['href_me'] . "</span";
+							echo "<span class='txt_highlight2'>" . $lang['href_me'] . "</span>";
 						}
 						else {
 						    echo "<a href='my_membership.php'>" . $lang['href_me'] . "</a>";
@@ -169,7 +169,7 @@ setTimeout( 'ShowTimeoutWarning();', session_maxlifetime_ms );
 
 						<?php
 						if (isset($section) && $section == "network") {
-						    echo "<span class='txt_highlight2'>" . $lang['href_network'] . "</span";
+						    echo "<span class='txt_highlight2'>" . $lang['href_network'] . "</span>";
 						}
 						else {
 						    echo "<a href='sn_network.php'>" . $lang['href_network'] . "</a>";
@@ -183,7 +183,7 @@ setTimeout( 'ShowTimeoutWarning();', session_maxlifetime_ms );
 					<td class="main_menu_td_content">
 						<?php
 						if (isset($section) && $section == "group") {
-						    echo "<span class='txt_highlight2'>" . $lang['href_groups'] . "</span";
+						    echo "<span class='txt_highlight2'>" . $lang['href_groups'] . "</span>";
 						}
 						else {
 						    echo "<a href='g_groups.php'>" . $lang['href_groups'] . "</a>";
@@ -196,7 +196,7 @@ setTimeout( 'ShowTimeoutWarning();', session_maxlifetime_ms );
 					<td class="main_menu_td_content">
 						<?php
 						if (isset($section) && $section == "schedule") {
-						    echo "<span class='txt_highlight2'>" . $lang['href_schedule'] . "</span";
+						    echo "<span class='txt_highlight2'>" . $lang['href_schedule'] . "</span>";
 						}
 						else {
 						    echo "<a href='sch_list.php'>" . $lang['href_schedule'] . "</a>";
@@ -206,6 +206,19 @@ setTimeout( 'ShowTimeoutWarning();', session_maxlifetime_ms );
 					<td class="main_menu_td_spacer">
 						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="1" alt="" border="0" /><br />
 					</td>
+					<td class="main_menu_td_content">
+						<?php
+						if (isset($section) && $section == "channel") {
+						    echo "<span class='txt_highlight2'>" . $lang['href_channels'] . "</span>";
+						}
+						else {
+						    echo "<a href='chl_overview.php'>" . $lang['href_channels'] . "</a>";
+						}
+						?><br />
+					</td>
+					<td class="main_menu_td_spacer">
+						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="1" alt="" border="0" /><br />
+					</td>
 					<td width="100%">
 						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="1" alt="" border="0" /><br />
 					</td>
@@ -459,6 +472,16 @@ setTimeout( 'ShowTimeoutWarning();', session_maxlifetime_ms );
 									} else {
 									?>
 									<a href="fil_list.php"><?php echo $lang['menu_files'];?></a>
+									<?php }?>
+									&nbsp;&#47;&nbsp;
+									<?php
+									if ($page_name_short == "chl_list") {
+									?>
+									<?php echo $lang['menu_channels'];?>
+									<?php
+									} else {
+									?>
+									<a href="chl_list.php"><?php echo $lang['menu_channels'];?></a>
 									<?php }?><br />
 
 								</td>
