@@ -285,17 +285,34 @@
 						if (isset($group)) {
 						?>
 						<table border="0" cellspacing="0" cellpadding="4" width="100%">
+							<?php
+							if ($this->group_acs->checkPermission($resource_ids['group_rsp'], $privilege_ids['allow_rsp_public'])) { //resource_id, Priv_id
+							?>
+							<tr>
+								<td valign="top">
+									<input id="id_allow_rsp_public" type="checkbox" name="rsp_public" class="checkbox" value="1" <?php if (isset($rsp_public) && $rsp_public == 1) { echo "checked=\"checked\"";}?> />
+								</td>
+								<td valign="top">
+									<label style="width:100%" for="id_allow_rsp_public"><?php echo $lang['txt_publish_public_help'];?></label><br />
+								</td>
+							</tr>
+							<tr>
+								<td colspan="2">
+									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
+								</td>
+							<tr>
+							<?php 
+							}
+							if ($this->group_acs->checkPermission($resource_ids['group_rsp'], $privilege_ids['allow_rsp_node'])) { //resource_id, Priv_id
+								if ($rspconfig['node']['auto_publish'] == 1) {
+									$txt_rsp_node = $lang['form_rsp_node_auto'];
+								}
+								else {
+									$txt_rsp_node = $lang['form_rsp_node'];
+								}
+							?>
 							<tr>
 								<td valign="top">
-									<?php
-									if ($this->group_acs->checkPermission($resource_ids['group_rsp'], $privilege_ids['allow_rsp_node'])) { //resource_id, Priv_id
-										if ($rspconfig['node']['auto_publish'] == 1) {
-										    $txt_rsp_node = $lang['form_rsp_node_auto'];
-										}
-										else {
-											$txt_rsp_node = $lang['form_rsp_node'];
-										}
-									?>
 									<input id="id_allow_rsp_node" type="checkbox" name="rsp_node" class="checkbox" value="1" <?php if (isset($rsp_node) && $rsp_node == 1) { echo "checked=\"checked\"";}?> />
 								</td>
 								<td valign="top">
@@ -307,19 +324,18 @@
 									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
 								</td>
 							<tr>
+							<?php
+							}
+							if ($this->group_acs->checkPermission($resource_ids['group_rsp'], $privilege_ids['allow_rsp_group_home'])) { //resource_id, Priv_id
+								if ($group['group_rsp_auto_publish'] == 1) {
+									$txt_rsp_group = $lang['form_rsp_group_auto'];
+								}
+								else {
+									$txt_rsp_group = $lang['form_rsp_group'];
+								}
+							?>
 							<tr>
 								<td valign="top">
-									<?php
-									}
-
-									if ($this->group_acs->checkPermission($resource_ids['group_rsp'], $privilege_ids['allow_rsp_group_home'])) { //resource_id, Priv_id
-										if ($group['group_rsp_auto_publish'] == 1) {
-										    $txt_rsp_group = $lang['form_rsp_group_auto'];
-										}
-										else {
-											$txt_rsp_group = $lang['form_rsp_group'];
-										}
-									?>
 									<input id="id_allow_rsp_group" type="checkbox" name="rsp_group" class="checkbox" value="1" <?php if (isset($rsp_group_home) && $rsp_group_home == 1) { echo "checked=\"checked\"";}?> /><br />
 								</td>
 								<td valign="top">
@@ -403,6 +419,7 @@
 							if ($this->user_acs->checkPermission($resource_ids['rsp'], $privilege_ids['allow_rsp_node'])) { //resourece_id, Priv_id
 							$selected="";
 							if (isset($rsp_node) && $rsp_node == 1) {
+								$selected=" checked=\"checked\"";
 							}
 							?>
 							<tr>
